package com.example.shoesapptest.screen

import android.app.Dialog
import androidx.compose.foundation.background
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.wrapContentSize
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.ModalBottomSheetDefaults
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.DialogProperties
import com.example.shoesapp.ui.theme.MatuleTheme
import com.example.shoesapptest.R
import androidx.compose.material3.AlertDialog
import androidx.compose.runtime.getValue
import androidx.compose.runtime.setValue

@Composable
fun ForgotPasswordScreen(){
    Scaffold(
        topBar = {
            Row(
                modifier = Modifier
                    .padding(top = 35.dp)
                    .fillMaxWidth()
                    .height(40.dp)
            ) {
                IconButton(onClick = {}) {
                    Icon(painter= painterResource(R.drawable.back_arrow),
                        contentDescription = null)
                }
            }
        }
    ){ paddingValues ->
        ScreenContent(paddingValues)
    }

}

@Composable
fun ScreenContent(paddingValues: PaddingValues){
Column(
    modifier = Modifier.padding(paddingValues = paddingValues)
){
    TitleWithSubtitleText(
        title = stringResource(R.string.title_forgot_password),
        subTitle = stringResource(R.string.subtitle_forgot_password)
    )
    val email = remember { mutableStateOf("") }
    Spacer(modifier = Modifier.height(35.dp))
    EmailTextField(
       placeHolderText = stringResource(R.string.placeholder_email),
        EmailValue = email.value,
        onEmailChange = {
            email.value=it
        }
    )
}
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun EmailTextField(EmailValue: String,
                   onEmailChange: (String) -> Unit,
                   placeHolderText: String){
    Column(
        modifier = Modifier
            .padding(20.dp)
            .wrapContentSize(),
        verticalArrangement = Arrangement.spacedBy(8.dp)
    ){
        val email = remember { MutableInteractionSource() }
        BasicTextField(
            value=EmailValue,
            onValueChange = {onEmailChange(it)},
            modifier = Modifier
                .padding(horizontal = 20.dp)
                .fillMaxWidth()
                .clip(RoundedCornerShape(14.dp))
                .background(MatuleTheme.colors.background)
        ){ innerTextField ->
            TextFieldDefaults.DecorationBox(
                value = EmailValue,
                singleLine = true,
                innerTextField = innerTextField,
                colors = TextFieldDefaults.colors(
                    focusedContainerColor = MatuleTheme.colors.background,
                    disabledContainerColor = MatuleTheme.colors.background,
                    unfocusedContainerColor = MatuleTheme.colors.background,
                    errorContainerColor = MatuleTheme.colors.background,
                    unfocusedIndicatorColor = Color.Transparent,
                    focusedIndicatorColor = Color.Transparent,
                    disabledIndicatorColor = Color.Transparent,
                    errorIndicatorColor = Color.Transparent
                ),
                visualTransformation = VisualTransformation.None,
                interactionSource = email,
                enabled = true,
                placeholder = {
                    if (placeHolderText != null)
                        Text(
                            text = placeHolderText,
                            style = MatuleTheme.typography.bodyRegular14.copy(color = MatuleTheme.colors.hint)
                        )
                }
            )
        }
        CommonButton(
            modifier = Modifier.padding(top=30.dp),
            buttonLabel = stringResource(R.string.send_email_forgot)
        ) {}
    }
}

@Composable
fun TitleWithSubtitleText(title: String, subTitle:String){
    Column(
        modifier = Modifier
            .padding(horizontal = 20.dp)
            .padding(top = 50.dp),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.spacedBy(10.dp)
    )
    {
        Text(
            text = title,
            style = MatuleTheme.typography.headingBold32.copy(color = MatuleTheme.colors.text),
            textAlign = TextAlign.Center
            )
        Text(
            text = subTitle,
            maxLines = 2,
            style = MatuleTheme.typography.subTitleRegular16.copy(color = MatuleTheme.colors.subTextDark),
            textAlign = TextAlign.Center
        )
    }

}


@Composable
fun CommonButton(modifier: Modifier, buttonLabel: String, onClick: () -> Unit){
    var showDialog by remember { mutableStateOf(false) }
    Button(

        modifier = modifier
            .padding(horizontal = 20.dp)
            .fillMaxWidth()
            .height(50.dp)
            .clip(RoundedCornerShape(14.dp))
            .background(MatuleTheme.colors.accent)
        ,
        colors = ButtonColors(
            containerColor = MatuleTheme.colors.accent,
            disabledContentColor = Color.Transparent,
            disabledContainerColor = MatuleTheme.colors.accent,
            contentColor = Color.Transparent
        ),
        onClick= {showDialog=true}
    ){
        Text(
            text=buttonLabel,
            style = MatuleTheme.typography.bodyRegular14.copy(color= MatuleTheme.colors.background),
            textAlign = TextAlign.Center
        )
    }
    if (showDialog) {
        CheckEmailDialog(onDismiss = { showDialog = false })
    }
}

@Composable
fun CheckEmailDialog(onDismiss: () -> Unit) {
    AlertDialog(
        onDismissRequest = onDismiss,
        confirmButton = {},
        title = {
            Column(
                horizontalAlignment = Alignment.CenterHorizontally,
                modifier = Modifier.fillMaxWidth()
            ) {
                Row(
                    modifier = Modifier.padding(bottom = 8.dp),
                    horizontalArrangement = Arrangement.Center
                ) {
                    Icon(
                        painter = painterResource(R.drawable.email_image),
                        contentDescription = null,
                        tint = MatuleTheme.colors.accent,
                        modifier = Modifier.size(40.dp)
                    )
                }
                Text(
                    text = "Проверьте Ваш Email",
                    style = MatuleTheme.typography.bodyRegular16.copy(color = MatuleTheme.colors.text),
                    textAlign = TextAlign.Center
                )
            }
        },
        text = {
            Text(
                text = "Мы отправили код восстановления пароля на вашу электронную почту.",
                textAlign = TextAlign.Center,
                style = MatuleTheme.typography.bodyRegular14.copy(color = MatuleTheme.colors.hint)
            )
        },
        modifier = Modifier.clip(RoundedCornerShape(14.dp)),
        containerColor = Color.White
    )
}






















